@@ -35,6 +35,7 @@ class Deploy(object):
         autoscaletarget=1000,
         wait=True,
         bucket=None,
+        prefix='',
         session=None,
         image=None,
         dockerfilepath=None,
@@ -60,6 +61,7 @@ class Deploy(object):
         self.image = image
         self.dockerfilepath = dockerfilepath
         self.ei = ei
+        self.prefix = prefix
         self.monitor = monitor
         self.deployed = False
         self.autoscaletarget = autoscaletarget
@@ -258,7 +260,13 @@ class Deploy(object):
 
     def choose_instance_type(self):
         # TO DO : add heuristic for auto selection of instance size
-        size = self.get_size(self.bucket, "ezsmdeploy/model-" + self.name + "/")
+        
+        if self.path =='':
+            tmppath = "ezsmdeploy/model-" + self.name + "/"
+        else:
+            tmppath = self.prefix+"/ezsmdeploy/model-" + self.name + "/"
+
+        size = self.get_size(self.bucket, tmppath )
 
         self.instancetypespath = pkg_resources.resource_filename(
             "ezsmdeploy", "data/instancetypes.csv"
@@ -346,13 +354,21 @@ class Deploy(object):
 
         if self.monitor:
             from sagemaker.model_monitor import DataCaptureConfig
-
+            
+            
+            if prefix == '':
+                tmps3uri = "s3://{}/ezsmdeploy/model-{}/datacapture".format(
+                    self.bucket, self.name
+                )
+            else:
+                tmps3uri = "s3://{}/{}/ezsmdeploy/model-{}/datacapture".format(
+                    self.bucket, self.prefix, self.name
+                )
+            
             data_capture_config = DataCaptureConfig(
                 enable_capture=True,
                 sampling_percentage=100,
-                destination_s3_uri="s3://{}/ezsmdeploy/model-{}/datacapture".format(
-                    self.bucket, self.name
-                ),
+                destination_s3_uri=tmps3uri
             )
         else:
             data_capture_config = None
@@ -381,13 +397,17 @@ class Deploy(object):
 
     def upload_model(self):
         i = 1
+        if self.prefix == '':
+            tmppath = "ezsmdeploy/model-"
+        else:
+            tmppath = self.path + "/ezsmdeploy/model-"
         self.modelpath = []
         for name in self.model:
             self.modelpath.append(
                 self.session.upload_data(
                     path="model{}.tar.gz".format(i),
                     bucket=self.bucket,
-                    key_prefix="ezsmdeploy/model-" + self.name,
+                    key_prefix=tmppath + self.name,
                 )
             )
             i += 1
@@ -397,14 +417,26 @@ class Deploy(object):
         i = 1
         for name in self.model:
 
-            if "s3" in name:
+            if "tar.gz" in name and 's3' in name:
                 # download and uncompress
                 self.session.download_data(
                     path="./downloads/{}".format(i),
                     bucket=name.split("/")[2],
                     key_prefix="/".join(name.split("/")[3:]),
                 )
+                
+                with tarfile.open(
+                    glob.glob("./downloads/{}/*.tar.gz".format(i))[0]
+                ) as tar:
+                    tar.extractall("./extractedmodel/{}/".format(i))
 
+                name = "extractedmodel/{}/".format(i)
+                
+            elif 'tar.gz' in name and 's3' not in name:
+                
+                self.makedir_safe("downloads")
+                shutil.copy(name, "./downloads/{}".format(i))
+                
                 with tarfile.open(
                     glob.glob("./downloads/{}/*.tar.gz".format(i))[0]
                 ) as tar:
